@@ -789,6 +789,20 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 'sharpe': 'epoch realized sharpe ratio',
                 'calmar': 'epoch realized calmar ratio',
                 'mdd': 'epoch realized max drawdown'})
+
+            epochkpis_df['epoch realized return'] = epochkpis_df['epoch realized return'].round(
+                decimals=2)
+            epochkpis_df['epoch realized annualized return'] = epochkpis_df[
+                'epoch realized annualized return'].round(decimals=2)
+            epochkpis_df['epoch realized annualized volatility'] = epochkpis_df[
+                'epoch realized annualized volatility'].round(decimals=2)
+            epochkpis_df['epoch realized sharpe ratio'] = epochkpis_df[
+                'epoch realized sharpe ratio'].round(decimals=2)
+            epochkpis_df['epoch realized calmar ratio'] = epochkpis_df[
+                'epoch realized calmar ratio'].round(decimals=2)
+            epochkpis_df['epoch realized max drawdown'] = epochkpis_df[
+                'epoch realized max drawdown'].round(decimals=2)
+
             if write_file:
                 writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{title}.xlsx',
                                         engine='xlsxwriter')
